@@ -1,6 +1,5 @@
 from ... import types
 from ...charts.chart import ThreeAxisChart
-from ...globals import ChartType
 from ...options import InitOpts
 
 
@@ -11,4 +10,4 @@ class Scatter3D(ThreeAxisChart):
 
     def __init__(self, init_opts: types.Init = InitOpts()):
         super().__init__(init_opts)
-        self._3d_chart_type = ChartType.SCATTER3D
+        self._3d_chart_type = "scatter3D"
