@@ -1,7 +1,5 @@
-from ... import options as opts
 from ... import types
 from ...charts.chart import ThreeAxisChart
-from ...globals import ChartType
 from ...options import InitOpts
 
 
@@ -12,4 +10,4 @@ class Surface3D(ThreeAxisChart):
 
     def __init__(self, init_opts: types.Init = InitOpts()):
         super().__init__(init_opts)
-        self._3d_chart_type = ChartType.SURFACE
+        self._3d_chart_type = "surface"
