@@ -4,7 +4,7 @@ class NonexistentCoordinatesException(Exception):
         self._coord_name = coord_name
 
     def __str__(self):
-        return f"当前地点: {self._coord_name} 坐标不存在, 错误原因: {self._error_msg}"
+        return "当前地点: {self._coord_name} 坐标不存在, 错误原因: {self._error_msg}".format(self=self)
 
 
 class WordCloudMaskImageException(Exception):
@@ -12,4 +12,4 @@ class WordCloudMaskImageException(Exception):
         self._data = data
 
     def __str__(self):
-        return f"错误原因: 图片无法加载或者不是一个正确的路径, 数据: {self._data}"
+        return "错误原因: 图片无法加载或者不是一个正确的路径, 数据: {self._data}".format(self=self)
