@@ -20,21 +20,6 @@ def test_map_base(fake_writer):
     assert_in("baseTexture", content)
 
 
-@patch("pyecharts.render.engine.write_utf8_html_file")
-def test_map_base_v2(fake_writer):
-    c = (
-        MapGlobe()
-        .add("商家A", [list(z) for z in zip(Faker.provinces, Faker.values())], "china")
-        .add_schema(maptype="china")
-    )
-    c.render()
-    _, content = fake_writer.call_args[0]
-    assert_in("document.createElement('canvas')", content)
-    assert_equal(c.theme, "white")
-    assert_equal(c.renderer, "canvas")
-    assert_in("baseTexture", content)
-
-
 def test_map_globe_in_jupyter():
     CurrentConfig.NOTEBOOK_TYPE = NotebookType.JUPYTER_NOTEBOOK
 
